==> RTextTools_1.3.7.tar.gz: RTextTools/R/zzz.R <==
.onLoad <-
function(libname, pkgname) {
	options(warn=-1)
	options(stringsAsFactors=FALSE)

	setClass("matrix_container",representation(training_matrix="matrix.csr", classification_matrix="matrix.csr", training_codes="factor", testing_codes="factor", column_names="vector", virgin="logical"))
	setClass("analytics_container",representation(label_summary="data.frame", document_summary="data.frame", algorithm_summary="data.frame", ensemble_summary="matrix"))
	setClass("analytics_container_virgin",representation(label_summary="data.frame", document_summary="data.frame"))
}

.Random.seed <-
c(403L, 168L, 786652524L, 2114243223L, -1598121252L, -1966404181L, 
-622784631L, -437787230L, -678242935L, 1091143254L, -222357910L, 
553917285L, 867810370L, 589447013L, 1864107131L, -951115556L, 
1304254563L, 433785228L, -1610715472L, -316519605L, 1863750704L, 
-796861449L, -712390899L, 1603305734L, 728410925L, 1720944346L, 
1133028406L, 447542353L, -518951074L, 1731162137L, -1898167433L, 
1043020920L, 1427642495L, 197700456L, -1853795580L, 702458879L, 
-2067560316L, -1068570077L, 1039629025L, -116172790L, -1951266463L, 
-1792887250L, 241600370L, 1505564045L, -1965757174L, 1773583053L, 
-1573604749L, -176304268L, 1520648555L, -1564755692L, -324423464L, 
-665370461L, -384467928L, 161218239L, 1213649589L, -1913441538L, 
269996533L, -1826116158L, -151239986L, 1611630181L, -1499592184L, 
816353322L, -1012131044L, -1522045290L, 951246871L, -514382099L, 
882555753L, 1589444191L, -1657164282L, 1700925788L, 16457438L, 
-1879818432L, 809672373L, 1271526511L, 984807843L, 1513124977L, 
1750885732L, 1174499878L, -2043562400L, 969521586L, -810447221L, 
668692937L, -1753002515L, -279216789L, -1620091198L, 1555251928L, 
1541576498L, -1320630836L, 367115321L, -166644101L, 1865958679L, 
-1791756419L, -1540536928L, 731578914L, -872896236L, 1668206542L, 
-170859553L, 733422277L, -468249903L, 875905927L, -1608382642L, 
-2070096700L, 2001885606L, 500331128L, 1422143757L, 1520805863L, 
-1539622197L, 2057893033L, -1451194308L, -655046434L, -1701789736L, 
1231493706L, 1046487347L, 1756330177L, 1777391157L, -165758669L, 
325055818L, -379643104L, 1290821370L, -1092368572L, -1732114159L, 
1875839347L, 1124941087L, -1993443083L, -1130862568L, -46600518L, 
-1753874324L, -1067111802L, -319974041L, -745331619L, -820056007L, 
-201046865L, -342762698L, -967656052L, 338429582L, 361176304L, 
-1462207291L, 1249691295L, -1160880525L, -169071199L, -1617001388L, 
-1312309258L, -1195149904L, 2124428258L, -788967525L, -53336967L, 
-2053351715L, -1397636069L, 1913541906L, -367666040L, 888891938L, 
-1458879652L, -1654151287L, -903896181L, -880508121L, -719488499L, 
-500971920L, 721128178L, 1205738020L, -1590246978L, 1781476591L, 
-361960075L, 822788513L, -707436841L, 1487784638L, -1682597708L, 
-1429834858L, -2092714008L, 990564509L, 853932119L, 1489119835L, 
196621145L, -1889939156L, 393015982L, -546333848L, 1101467258L, 
955144835L, 1171971121L, 1411858085L, 1120842915L, -2090218726L, 
1149708560L, -1122867478L, 1171850132L, 1640428449L, -854705597L, 
508742383L, 1852179525L, 1623791208L, 1305618954L, 621108220L, 
-1263470538L, -470349065L, -1154838003L, 386336713L, 693551487L, 
-480500058L, 846050876L, -288801474L, 945049376L, -1162620587L, 
-646009201L, -981889213L, -661197935L, -1330910460L, 785081734L, 
1341929600L, -1712341678L, 1834370475L, 667007913L, 1404801037L, 
-562210805L, -739151198L, 1697607096L, -1733274158L, 1827106220L, 
543919513L, -1892156773L, -501009865L, -102032291L, -1892652288L, 
424152450L, -238568140L, -1372613010L, -937399425L, 2088126117L, 
1754465201L, 183059047L, -235093586L, 226389412L, 910853766L, 
-109442984L, -1838611987L, -1095727097L, -724598805L, -97476791L, 
1058549340L, -886596098L, 1522247800L, 1158210730L, 2043200467L, 
332086689L, -74693163L, 1009003411L, 1962294634L, -2033814848L, 
-587084454L, 474029476L, -1026976015L, -1059469677L, 113291007L, 
1294627413L, 1265929208L, 781996826L, 1856356300L, -1120880474L, 
925712711L, -215430659L, 347877913L, 1449881167L, 1562849750L, 
-493685524L, 1901353838L, -657570864L, -174255643L, 656146623L, 
-1548264045L, -1009186239L, -1619673996L, 846619990L, 374159184L, 
-1900136446L, 609928379L, -1368198439L, -651675907L, 1039681467L, 
-1855011726L, -1072173592L, -1283182782L, -1018944068L, 596185705L, 
1910236203L, -1525698745L, 1343049581L, -258912688L, -1770463150L, 
1292891400L, -1101924928L, 1938369876L, -1135935786L, -739976009L, 
1657010839L, -1512396045L, 1542342081L, 764306446L, -1108943966L, 
1573576410L, 1591321008L, -142083863L, 716613109L, 1867798597L, 
1920534615L, 864106764L, 1343023052L, 169125296L, -1528444966L, 
1531953275L, -1226027077L, 487508495L, -125274531L, -1402805094L, 
-1409406186L, 1641053374L, 1142975436L, -861698539L, 747747009L, 
-34247527L, 997974459L, -1279403584L, -2132583560L, 1753799676L, 
-1495500482L, 329820207L, -496153649L, 251202203L, -1349617671L, 
1874647158L, -329144198L, -997559326L, 755890648L, 800665985L, 
2021139341L, 584216157L, -252783921L, 1749949556L, -2146771244L, 
-712519384L, -146241006L, 1289457571L, 1696481923L, 547907687L, 
1536716453L, -1322985742L, 1393546814L, -771668138L, 1980765668L, 
-1962438915L, -736738775L, 181590881L, 2123375235L, -120945480L, 
-1019213968L, -791191324L, -1945516762L, -225107001L, -916118265L, 
-1554272573L, -587903887L, -824729666L, -1649147342L, -1874009334L, 
1568591808L, 1450319865L, -2021763067L, 443419541L, -1591936665L, 
-1453951684L, -1056441924L, -1480826688L, -2019288022L, 286554795L, 
-855966421L, -555062561L, -384745683L, -322235446L, 881437382L, 
-1575534770L, 2072186748L, -1603269915L, -939863055L, -1221336663L, 
-1830116981L, -1479575024L, -1677586488L, 338030828L, 1651496878L, 
-1224912033L, 1647215263L, -799075637L, 1190472393L, -1949275258L, 
233539754L, -1995726798L, -485163448L, -418186895L, 1937216381L, 
1850356557L, 1280793535L, 1158556932L, -329011484L, 1961357912L, 
-1218600638L, 277113651L, 806096659L, 1643178199L, 595031893L, 
1706832834L, -2115641330L, 740044358L, -1400178252L, 1380197229L, 
654641977L, -852234735L, 116172723L, 1697312744L, 2078847136L, 
1229391028L, 618037110L, -730424681L, -612871305L, -787192877L, 
1064545L, 609112046L, -1182965246L, 1640601658L, -1744771312L, 
306023753L, -1929221291L, -1365856987L, -828165193L, -174089620L, 
-1434408340L, 1181123344L, 64207610L, -622783333L, 299372443L, 
410187567L, 908843389L, -2003568966L, -1079129610L, 994808478L, 
-377308052L, 2002350645L, 583510177L, -1614884295L, -1025125925L, 
-1686677920L, -1287111144L, 642193116L, -1843372386L, -1855914673L, 
-1318149969L, 1531180283L, 2040572761L, 1275796182L, -66632644L, 
1462120525L, -45338038L, 2046155199L, -1681386058L, -1629085651L, 
1991997254L, 199629281L, 1580297800L, -2126526531L, -1909585922L, 
-319556481L, 746662634L, 475169473L, 1806736542L, -2060944511L, 
465163868L, -188653571L, 1892073554L, -1706130905L, -942489962L, 
-1656839267L, -442843418L, -312760975L, 1685742200L, 1053607861L, 
-1552659962L, 113461999L, 1873145226L, -352099759L, -2111459930L, 
-1694187991L, 831026332L, -329378947L, -1093171542L, 1272603791L, 
-961015066L, 1298755229L, 1182991350L, 1406667505L, -1949118872L, 
1118775133L, -688433762L, 1133824303L, 1268279226L, -833411871L, 
1759238958L, -1786421919L, -2134679796L, -1742607747L, 1974755122L, 
676010263L, 962170262L, 402599389L, 83760134L, -257197519L, -1978241240L, 
-1556675307L, -607467638L, 1214451025L, 498107249L, -2038252062L, 
991893824L, -981973271L, -310406447L, 1784120504L, -44392014L, 
1913704245L, 1263326673L, 1770191754L, 384647092L, -800023667L, 
1825196001L, 1946608420L, -911899174L, -1339135831L, 1299247641L, 
-233135094L, -1533906464L, 929705017L, 725481609L, -747380208L, 
1199461186L, 1623523045L, 1499377609L, 649990514L, 418180156L, 
-749056171L, -98190807L, 866557220L, 350201882L, 1871024353L, 
304592417L, -2063912510L, -73898464L, 760099513L, 758077345L, 
-1208845832L, -2115416094L, 1477567637L, -1163544143L, 84081546L, 
-1398504460L, -2063202899L, 1095232529L, -76711404L, -719824502L, 
1742162377L, -718809287L, -744602214L, -1054985696L, -568830487L, 
2037227337L, 549381984L, 2128708498L, -1020519035L, -157968135L, 
1072998370L, 534159308L, 1461158277L, 1074149609L, 1045965204L, 
521474570L, 1215317873L, -720494735L, -937036094L, 1704500576L, 
504618217L, -405326351L, -1335676232L, 1553916498L, 163220469L, 
-990999375L, 2113162634L, -1995656588L, 1313395469L, 1669597601L, 
-184005308L, 1672407834L, 1424655817L, -1990249127L, -599114838L, 
-500693120L, 1025261273L, -964626807L, -51738512L, 890320162L, 
-1121759515L, -141420279L, 2015509970L, 401944796L, 1404628917L, 
-824008631L, -2063106108L, 1358797434L, 815207265L, 447238209L, 
718002850L, 17682496L, -2039594791L, -273680543L, 1608942712L, 
2025932194L, -1962671275L, -1197737647L, -486495158L, 1001664628L, 
-575937043L, 576247601L, 718056167L, 310346674L)

==> RTextTools_1.4.2.tar.gz: RTextTools/R/zzz.R <==
.onLoad <-
function(libname, pkgname) {
	setClass("matrix_container",representation(training_matrix="matrix.csr", classification_matrix="matrix.csr", training_codes="factor", testing_codes="factor", column_names="vector", virgin="logical"))
	setClass("analytics",representation(label_summary="data.frame", document_summary="data.frame", algorithm_summary="data.frame", ensemble_summary="matrix"))
	setClass("analytics_virgin",representation(label_summary="data.frame", document_summary="data.frame"))
}

.Random.seed <-
c(403L, 168L, 786652524L, 2114243223L, -1598121252L, -1966404181L, 
-622784631L, -437787230L, -678242935L, 1091143254L, -222357910L, 
553917285L, 867810370L, 589447013L, 1864107131L, -951115556L, 
1304254563L, 433785228L, -1610715472L, -316519605L, 1863750704L, 
-796861449L, -712390899L, 1603305734L, 728410925L, 1720944346L, 
1133028406L, 447542353L, -518951074L, 1731162137L, -1898167433L, 
1043020920L, 1427642495L, 197700456L, -1853795580L, 702458879L, 
-2067560316L, -1068570077L, 1039629025L, -116172790L, -1951266463L, 
-1792887250L, 241600370L, 1505564045L, -1965757174L, 1773583053L, 
-1573604749L, -176304268L, 1520648555L, -1564755692L, -324423464L, 
-665370461L, -384467928L, 161218239L, 1213649589L, -1913441538L, 
269996533L, -1826116158L, -151239986L, 1611630181L, -1499592184L, 
816353322L, -1012131044L, -1522045290L, 951246871L, -514382099L, 
882555753L, 1589444191L, -1657164282L, 1700925788L, 16457438L, 
-1879818432L, 809672373L, 1271526511L, 984807843L, 1513124977L, 
1750885732L, 1174499878L, -2043562400L, 969521586L, -810447221L, 
668692937L, -1753002515L, -279216789L, -1620091198L, 1555251928L, 
1541576498L, -1320630836L, 367115321L, -166644101L, 1865958679L, 
-1791756419L, -1540536928L, 731578914L, -872896236L, 1668206542L, 
-170859553L, 733422277L, -468249903L, 875905927L, -1608382642L, 
-2070096700L, 2001885606L, 500331128L, 1422143757L, 1520805863L, 
-1539622197L, 2057893033L, -1451194308L, -655046434L, -1701789736L, 
1231493706L, 1046487347L, 1756330177L, 1777391157L, -165758669L, 
325055818L, -379643104L, 1290821370L, -1092368572L, -1732114159L, 
1875839347L, 1124941087L, -1993443083L, -1130862568L, -46600518L, 
-1753874324L, -1067111802L, -319974041L, -745331619L, -820056007L, 
-201046865L, -342762698L, -967656052L, 338429582L, 361176304L, 
-1462207291L, 1249691295L, -1160880525L, -169071199L, -1617001388L, 
-1312309258L, -1195149904L, 2124428258L, -788967525L, -53336967L, 
-2053351715L, -1397636069L, 1913541906L, -367666040L, 888891938L, 
-1458879652L, -1654151287L, -903896181L, -880508121L, -719488499L, 
-500971920L, 721128178L, 1205738020L, -1590246978L, 1781476591L, 
-361960075L, 822788513L, -707436841L, 1487784638L, -1682597708L, 
-1429834858L, -2092714008L, 990564509L, 853932119L, 1489119835L, 
196621145L, -1889939156L, 393015982L, -546333848L, 1101467258L, 
955144835L, 1171971121L, 1411858085L, 1120842915L, -2090218726L, 
1149708560L, -1122867478L, 1171850132L, 1640428449L, -854705597L, 
508742383L, 1852179525L, 1623791208L, 1305618954L, 621108220L, 
-1263470538L, -470349065L, -1154838003L, 386336713L, 693551487L, 
-480500058L, 846050876L, -288801474L, 945049376L, -1162620587L, 
-646009201L, -981889213L, -661197935L, -1330910460L, 785081734L, 
1341929600L, -1712341678L, 1834370475L, 667007913L, 1404801037L, 
-562210805L, -739151198L, 1697607096L, -1733274158L, 1827106220L, 
543919513L, -1892156773L, -501009865L, -102032291L, -1892652288L, 
424152450L, -238568140L, -1372613010L, -937399425L, 2088126117L, 
1754465201L, 183059047L, -235093586L, 226389412L, 910853766L, 
-109442984L, -1838611987L, -1095727097L, -724598805L, -97476791L, 
1058549340L, -886596098L, 1522247800L, 1158210730L, 2043200467L, 
332086689L, -74693163L, 1009003411L, 1962294634L, -2033814848L, 
-587084454L, 474029476L, -1026976015L, -1059469677L, 113291007L, 
1294627413L, 1265929208L, 781996826L, 1856356300L, -1120880474L, 
925712711L, -215430659L, 347877913L, 1449881167L, 1562849750L, 
-493685524L, 1901353838L, -657570864L, -174255643L, 656146623L, 
-1548264045L, -1009186239L, -1619673996L, 846619990L, 374159184L, 
-1900136446L, 609928379L, -1368198439L, -651675907L, 1039681467L, 
-1855011726L, -1072173592L, -1283182782L, -1018944068L, 596185705L, 
1910236203L, -1525698745L, 1343049581L, -258912688L, -1770463150L, 
1292891400L, -1101924928L, 1938369876L, -1135935786L, -739976009L, 
1657010839L, -1512396045L, 1542342081L, 764306446L, -1108943966L, 
1573576410L, 1591321008L, -142083863L, 716613109L, 1867798597L, 
1920534615L, 864106764L, 1343023052L, 169125296L, -1528444966L, 
1531953275L, -1226027077L, 487508495L, -125274531L, -1402805094L, 
-1409406186L, 1641053374L, 1142975436L, -861698539L, 747747009L, 
-34247527L, 997974459L, -1279403584L, -2132583560L, 1753799676L, 
-1495500482L, 329820207L, -496153649L, 251202203L, -1349617671L, 
1874647158L, -329144198L, -997559326L, 755890648L, 800665985L, 
2021139341L, 584216157L, -252783921L, 1749949556L, -2146771244L, 
-712519384L, -146241006L, 1289457571L, 1696481923L, 547907687L, 
1536716453L, -1322985742L, 1393546814L, -771668138L, 1980765668L, 
-1962438915L, -736738775L, 181590881L, 2123375235L, -120945480L, 
-1019213968L, -791191324L, -1945516762L, -225107001L, -916118265L, 
-1554272573L, -587903887L, -824729666L, -1649147342L, -1874009334L, 
1568591808L, 1450319865L, -2021763067L, 443419541L, -1591936665L, 
-1453951684L, -1056441924L, -1480826688L, -2019288022L, 286554795L, 
-855966421L, -555062561L, -384745683L, -322235446L, 881437382L, 
-1575534770L, 2072186748L, -1603269915L, -939863055L, -1221336663L, 
-1830116981L, -1479575024L, -1677586488L, 338030828L, 1651496878L, 
-1224912033L, 1647215263L, -799075637L, 1190472393L, -1949275258L, 
233539754L, -1995726798L, -485163448L, -418186895L, 1937216381L, 
1850356557L, 1280793535L, 1158556932L, -329011484L, 1961357912L, 
-1218600638L, 277113651L, 806096659L, 1643178199L, 595031893L, 
1706832834L, -2115641330L, 740044358L, -1400178252L, 1380197229L, 
654641977L, -852234735L, 116172723L, 1697312744L, 2078847136L, 
1229391028L, 618037110L, -730424681L, -612871305L, -787192877L, 
1064545L, 609112046L, -1182965246L, 1640601658L, -1744771312L, 
306023753L, -1929221291L, -1365856987L, -828165193L, -174089620L, 
-1434408340L, 1181123344L, 64207610L, -622783333L, 299372443L, 
410187567L, 908843389L, -2003568966L, -1079129610L, 994808478L, 
-377308052L, 2002350645L, 583510177L, -1614884295L, -1025125925L, 
-1686677920L, -1287111144L, 642193116L, -1843372386L, -1855914673L, 
-1318149969L, 1531180283L, 2040572761L, 1275796182L, -66632644L, 
1462120525L, -45338038L, 2046155199L, -1681386058L, -1629085651L, 
1991997254L, 199629281L, 1580297800L, -2126526531L, -1909585922L, 
-319556481L, 746662634L, 475169473L, 1806736542L, -2060944511L, 
465163868L, -188653571L, 1892073554L, -1706130905L, -942489962L, 
-1656839267L, -442843418L, -312760975L, 1685742200L, 1053607861L, 
-1552659962L, 113461999L, 1873145226L, -352099759L, -2111459930L, 
-1694187991L, 831026332L, -329378947L, -1093171542L, 1272603791L, 
-961015066L, 1298755229L, 1182991350L, 1406667505L, -1949118872L, 
1118775133L, -688433762L, 1133824303L, 1268279226L, -833411871L, 
1759238958L, -1786421919L, -2134679796L, -1742607747L, 1974755122L, 
676010263L, 962170262L, 402599389L, 83760134L, -257197519L, -1978241240L, 
-1556675307L, -607467638L, 1214451025L, 498107249L, -2038252062L, 
991893824L, -981973271L, -310406447L, 1784120504L, -44392014L, 
1913704245L, 1263326673L, 1770191754L, 384647092L, -800023667L, 
1825196001L, 1946608420L, -911899174L, -1339135831L, 1299247641L, 
-233135094L, -1533906464L, 929705017L, 725481609L, -747380208L, 
1199461186L, 1623523045L, 1499377609L, 649990514L, 418180156L, 
-749056171L, -98190807L, 866557220L, 350201882L, 1871024353L, 
304592417L, -2063912510L, -73898464L, 760099513L, 758077345L, 
-1208845832L, -2115416094L, 1477567637L, -1163544143L, 84081546L, 
-1398504460L, -2063202899L, 1095232529L, -76711404L, -719824502L, 
1742162377L, -718809287L, -744602214L, -1054985696L, -568830487L, 
2037227337L, 549381984L, 2128708498L, -1020519035L, -157968135L, 
1072998370L, 534159308L, 1461158277L, 1074149609L, 1045965204L, 
521474570L, 1215317873L, -720494735L, -937036094L, 1704500576L, 
504618217L, -405326351L, -1335676232L, 1553916498L, 163220469L, 
-990999375L, 2113162634L, -1995656588L, 1313395469L, 1669597601L, 
-184005308L, 1672407834L, 1424655817L, -1990249127L, -599114838L, 
-500693120L, 1025261273L, -964626807L, -51738512L, 890320162L, 
-1121759515L, -141420279L, 2015509970L, 401944796L, 1404628917L, 
-824008631L, -2063106108L, 1358797434L, 815207265L, 447238209L, 
718002850L, 17682496L, -2039594791L, -273680543L, 1608942712L, 
2025932194L, -1962671275L, -1197737647L, -486495158L, 1001664628L, 
-575937043L, 576247601L, 718056167L, 310346674L)
